==> haskell-persistent-2.14.5.2-49-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent
version:              2.14.5.2
visibility:           public
id:                   persistent-2.14.5.2-9eq8y6ZCNqR84OxLjl0e2k
key:                  persistent-2.14.5.2-9eq8y6ZCNqR84OxLjl0e2k
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Type-safe, multi-backend data serialization.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent>.

category:             Database, Yesod
abi:                  0655d7ce90c2d738bdd5426613c262c8
exposed:              True
exposed-modules:
    Database.Persist Database.Persist.Class
    Database.Persist.Class.PersistConfig
    Database.Persist.Class.PersistEntity
    Database.Persist.Class.PersistField
    Database.Persist.Class.PersistQuery
    Database.Persist.Class.PersistStore
    Database.Persist.Class.PersistUnique Database.Persist.Compatible
    Database.Persist.EntityDef Database.Persist.EntityDef.Internal
    Database.Persist.FieldDef Database.Persist.FieldDef.Internal
    Database.Persist.ImplicitIdDef
    Database.Persist.ImplicitIdDef.Internal Database.Persist.Names
    Database.Persist.PersistValue Database.Persist.Quasi
    Database.Persist.Quasi.Internal Database.Persist.Sql
    Database.Persist.Sql.Migration Database.Persist.Sql.Types.Internal
    Database.Persist.Sql.Util Database.Persist.SqlBackend
    Database.Persist.SqlBackend.Internal
    Database.Persist.SqlBackend.Internal.InsertSqlResult
    Database.Persist.SqlBackend.Internal.IsolationLevel
    Database.Persist.SqlBackend.Internal.MkSqlBackend
    Database.Persist.SqlBackend.Internal.SqlPoolHooks
    Database.Persist.SqlBackend.Internal.Statement
    Database.Persist.SqlBackend.Internal.StatementCache
    Database.Persist.SqlBackend.SqlPoolHooks
    Database.Persist.SqlBackend.StatementCache Database.Persist.TH
    Database.Persist.Types

hidden-modules:
    Database.Persist.Types.Base Database.Persist.Sql.Internal
    Database.Persist.Sql.Types Database.Persist.Sql.Raw
    Database.Persist.Sql.Run Database.Persist.Sql.Class
    Database.Persist.Sql.Orphan.PersistQuery
    Database.Persist.Sql.Orphan.PersistStore
    Database.Persist.Sql.Orphan.PersistUnique
    Database.Persist.Compatible.Types Database.Persist.Compatible.TH

import-dirs:          /usr/lib/ghc-9.6.6/site-local/persistent-2.14.5.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/persistent-2.14.5.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/persistent-2.14.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent
hs-libraries:         HSpersistent-2.14.5.2-9eq8y6ZCNqR84OxLjl0e2k
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y
    attoparsec-0.14.4-68EOoedQqwu8mpKj0RmtvE
    attoparsec-aeson-2.1.0.0-BEiLkT0rdCWAen0nBrmaBS base-4.18.2.1
    base64-bytestring-1.2.1.0-AZbYiNuTo1lLfA6t4c9Fhh
    blaze-html-0.9.2.0-5pCa6Zd2ytCBxKPCiAVcIx bytestring-0.11.5.3
    conduit-1.3.6.1-5afbFXdQmpuHK8N5OCErlh containers-0.6.7
    deepseq-1.4.8.1 fast-logger-3.2.4-AXHM12y5MtZKIIwsnmTfyz
    http-api-data-0.6.1-6b8SlzeGz22trXyYobem
    lift-type-0.1.2.0-HvwG7YqtvqS40n7Rpizb92
    monad-logger-0.3.42-A8mPheDcfh1Ekf5r4bHp7w mtl-2.3.1
    path-pieces-0.2.1-ILPSumWqTsA51OyVDS7ISl
    resource-pool-0.2.3.2-73AdA0RAXUL5Z2VU9q4gfk
    resourcet-1.2.6-7GW6wEwAkCf499WYv26LMs
    scientific-0.3.8.0-JR5ijS18eRDLRLPoHGHkyW
    silently-1.2.5.4-BeJQMFrht8zIosElyGUCP7 template-haskell-2.20.0.0
    text-2.0.2 th-lift-instances-0.1.20-LTMKJZnS7WY2o6yRFgu9GC
    time-1.12.2 transformers-0.6.1.0
    unliftio-0.2.25.1-6Q6KWrgvoh1DxBXv7luml2
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    vault-0.3.1.5-A9Ty7yzuPZlIa80zuSIl14
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:   /usr/share/doc/haskell-persistent/html/persistent.haddock
haddock-html:         /usr/share/doc/haskell-persistent/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-2.14.5.2-51-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent
version:              2.14.5.2
visibility:           public
id:                   persistent-2.14.5.2-6kV56HNszVGH9bHqEA96Jq
key:                  persistent-2.14.5.2-6kV56HNszVGH9bHqEA96Jq
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Type-safe, multi-backend data serialization.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent>.

category:             Database, Yesod
abi:                  d2c17a30ea0251decb146969c781a235
exposed:              True
exposed-modules:
    Database.Persist Database.Persist.Class
    Database.Persist.Class.PersistConfig
    Database.Persist.Class.PersistEntity
    Database.Persist.Class.PersistField
    Database.Persist.Class.PersistQuery
    Database.Persist.Class.PersistStore
    Database.Persist.Class.PersistUnique Database.Persist.Compatible
    Database.Persist.EntityDef Database.Persist.EntityDef.Internal
    Database.Persist.FieldDef Database.Persist.FieldDef.Internal
    Database.Persist.ImplicitIdDef
    Database.Persist.ImplicitIdDef.Internal Database.Persist.Names
    Database.Persist.PersistValue Database.Persist.Quasi
    Database.Persist.Quasi.Internal Database.Persist.Sql
    Database.Persist.Sql.Migration Database.Persist.Sql.Types.Internal
    Database.Persist.Sql.Util Database.Persist.SqlBackend
    Database.Persist.SqlBackend.Internal
    Database.Persist.SqlBackend.Internal.InsertSqlResult
    Database.Persist.SqlBackend.Internal.IsolationLevel
    Database.Persist.SqlBackend.Internal.MkSqlBackend
    Database.Persist.SqlBackend.Internal.SqlPoolHooks
    Database.Persist.SqlBackend.Internal.Statement
    Database.Persist.SqlBackend.Internal.StatementCache
    Database.Persist.SqlBackend.SqlPoolHooks
    Database.Persist.SqlBackend.StatementCache Database.Persist.TH
    Database.Persist.Types

hidden-modules:
    Database.Persist.Types.Base Database.Persist.Sql.Internal
    Database.Persist.Sql.Types Database.Persist.Sql.Raw
    Database.Persist.Sql.Run Database.Persist.Sql.Class
    Database.Persist.Sql.Orphan.PersistQuery
    Database.Persist.Sql.Orphan.PersistStore
    Database.Persist.Sql.Orphan.PersistUnique
    Database.Persist.Compatible.Types Database.Persist.Compatible.TH

import-dirs:          /usr/lib/ghc-9.6.6/site-local/persistent-2.14.5.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/persistent-2.14.5.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/persistent-2.14.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent
hs-libraries:         HSpersistent-2.14.5.2-6kV56HNszVGH9bHqEA96Jq
depends:
    aeson-2.2.0.0-Hqy1Zqe0ZE81dk2L20icmH
    attoparsec-0.14.4-8hLS1m777hPFjiaInp95BL
    attoparsec-aeson-2.2.0.0-1Dj4q6tPpHs6SGokkiN3Ch base-4.18.2.1
    base64-bytestring-1.2.1.0-LrCtfbXf96jILPXKH7KAXZ
    blaze-html-0.9.2.0-AqjQr4Ps51QD51ybemU3ZY bytestring-0.11.5.3
    conduit-1.3.6.1-CwUx671uWmDAcHwxI0YYDy containers-0.6.7
    deepseq-1.4.8.1 fast-logger-3.2.4-Jiy7JoGUrfbVNzVDnbkpD
    http-api-data-0.6.1-5scq1iPo1rG2PjoFBDCc52
    lift-type-0.1.2.0-D32kLsUeaB0D2hhAaskeUM
    monad-logger-0.3.42-JqeTk6zPcDZE7ttxNu3qt7 mtl-2.3.1
    path-pieces-0.2.1-ILPSumWqTsA51OyVDS7ISl
    resource-pool-0.2.3.2-L0VqdQVTxp4Jxj0uaN0BCK
    resourcet-1.2.6-JtO0n9rtgTt543EMYn7K77
    scientific-0.3.8.0-E8K90IhCZpR98POp8HwlML
    silently-1.2.5.4-BeJQMFrht8zIosElyGUCP7 template-haskell-2.20.0.0
    text-2.0.2 th-lift-instances-0.1.20-LmKvjtmDbB28aBAJ5h65zr
    time-1.12.2 transformers-0.6.1.0
    unliftio-0.2.25.1-DOqhOSuyr6GEMTQhxoBZ0V
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-1hrud2F05KV7Rz7RsKTZ5O
    vault-0.3.1.5-BxUCdgn4AEk2ZyHGBzL9yO
    vector-0.13.2.0-DULMVARQ1CU3TLBOg9xkS6

haddock-interfaces:   /usr/share/doc/haskell-persistent/html/persistent.haddock
haddock-html:         /usr/share/doc/haskell-persistent/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
